@@ -1,3 +1,4 @@
+from json import encoder
 from flask import Flask, request
 from flask_cors import CORS #, cross_origin
 import json
@@ -163,9 +164,12 @@ def repo_status():
 @app.route('/search', methods=['POST'])
 def search_tx():
     ''' Search Transactions - Register '''
+    from cashiersync.ledger_output_parser import LedgerOutputParser
+    from cashiersync.model import TransactionEncoder
+
     #query = request.args.get('query')
-    json = request.get_json()
-    query = json['query']
+    request_json = request.get_json()
+    query = request_json['query']
     app.logger.debug(query)
 
     freeText = query['freeText']
@@ -182,7 +186,17 @@ def search_tx():
 
     ledger = LedgerExecutor(app.logger)
     result = ledger.run(params)
-    return result
+
+    lines = result.split('\n')
+    parser = LedgerOutputParser()
+    lines = parser.clean_up_register_output(lines)
+
+    txs = parser.get_rows_from_register(lines)
+    #return result
+    #encoded = TransactionEncoder().encode(txs)
+    encoded = json.dumps(txs, cls=TransactionEncoder)
+    #return json.dumps(txs)
+    return encoded
 
 @app.route('/securitydetails')
 def security_details():
